@@ -1,7 +1,7 @@
 # Copyright Notice:
 # Copyright 2016-2021 DMTF. All rights reserved.
 # License: BSD 3-Clause License. For full text see link:
-# https://github.com/chhuang789
+# https://github.com/DMTF/python-redfish-library/blob/master/LICENSE.md
 
 # -*- coding: utf-8 -*-
 """Helper module for working with REST technology."""
@@ -65,12 +65,14 @@ class BadRequestError(Exception):
 
 
 class redfish_advantech:
-    def __init__(self, hostname, port, username, password):
+    def __init__(self, hostname, port, username, password, nLogLevel=0):
+        self.__logVerbose = nLogLevel
         # Load logging.conf
         logging.config.fileConfig('logging.conf')
         # create logger
         self.logger = logging.getLogger('simpleExample')
-        self.logger.info('=== Start to of redfish_advantech.__init__ ===')
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug('=== Start to of redfish_advantech.__init__ ===')
 
         ssl._create_default_https_context = ssl._create_unverified_context
 
@@ -97,18 +99,20 @@ class redfish_advantech:
         self.lstURL = []
         self.nCount = 0
         self.nIndex = 0
+        self.lstURL2 = []
+        self.nCount2 = 0
+        self.nIndex2 = 0
         self.urlLogEntries = ''
-        self.__logVerbose = 0  # 1111
 
     def log(self, msg):
         self.logger.info("%s [hostname=%s port%d]",
                          msg, self.hostname, self.port)
 
-    def get_logVerbose(self):  # 1111
+    def get_logVerbose(self):
         """Return the level of log verbose"""
         return self.__logVerbose
 
-    def set_logVerbose(self, logVerbose=0):  # 1111
+    def set_logVerbose(self, logVerbose=0):
         """Set log Verbose level
 
         :param logVerbose: The level of log verbose to be set.
@@ -118,18 +122,26 @@ class redfish_advantech:
         self.__logVerbose = logVerbose
 
     def __del__(self):
-        self.logger.info('=== Destroy of redfish_advantech.__del__ ===')
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug('=== Destroy of redfish_advantech.__del__ ===')
 
     def __enter__(self):
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug('=== redfish_advantech.__enter__ ===')
         self.login()
         return self
 
     def __exit__(self, exc_type, exc_value, exc_traceback):
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug('=== redfish_advantech.__exit__ ===')
         self.logout()
         self.disconnect()
 
     # Redfish http request
     def rfRequest(self, log=True):
+        if (self.get_logVerbose() >= 1 and log): 
+            self.logger.debug('=== redfish_advantech.rfRequest ===')
+        response = None
         if (self.authToken == None):  # for login only
             headers = {'Accept': '*/*',
                        'self.connection': 'Keep-Alive', 'OData-Version': '4.0'}
@@ -141,19 +153,20 @@ class redfish_advantech:
                 self.logger.info(
                     "--> rfRequest [%s %s]", self.method, self.url)
                 if (self.payload == None):
-                    if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 0):
-                        self.logger.debug("headers=%s", headers)
+                    self.logger.debug("headers=%s", headers)
                 else:
-                    if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 0):
-                        self.logger.debug("headers=%s", headers)
-                        self.logger.debug("self.payload=%s", self.payload)
-            if (self.payload == None):
-                self.connection.request(
-                    self.method, self.url, self.payload, headers)
+                    self.logger.debug("headers=%s", headers)
+                    self.logger.debug("self.payload=%s", self.payload)
+            if (self.connection):
+                if (self.payload == None):
+                    self.connection.request(
+                        self.method, self.url, self.payload, headers)
+                else:
+                    self.connection.request(
+                        self.method, self.url, json.dumps(self.payload), headers)
+                response = self.connection.getresponse()
             else:
-                self.connection.request(
-                    self.method, self.url, json.dumps(self.payload), headers)
-            response = self.connection.getresponse()
+                self.logger.error("self.connection is None")
         except Exception as e:
             self.logger.error(e)
 
@@ -174,6 +187,8 @@ class redfish_advantech:
         :returns: returns a rest request with method 'Get'
 
         """
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug('=== redfish_advantech.get ===')
         self.url = path
         self.method = "GET"
         try:
@@ -183,14 +198,79 @@ class redfish_advantech:
                 "Error in json decoding. path=%s, method=%s", self.url, self.method)
             raise JsonDecodingError('Error in json decoding.')
 
+    # Get Redfish V1 root
+    def getRedfishV1(self):
+        self.method = "GET"
+        self.url = "/redfish/v1"
+        self.logger.info(
+            "--> getRedfishV1 [%s %s]", self.method, self.url)
+        self.payload = None
+        if (self.connection == None):
+            self.connection = http.client.HTTPSConnection(
+                self.hostname, self.port, timeout=self.theTimeout)
+            self.logger.debug("Start the http connection")
+        response = self.rfRequest()
+        # Get the next link of getRedfishV1
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if (i[0] in {"OData", "SessionService", "AccountService", "EventService", "Systems", "Chassis", "Managers", "Links"}):
+                    json_data2 = i[1]
+                    for ii in json_data2.items():
+                        if ii[0] == '@odata.id':
+                            self.lstURL.append(ii[1])
+                            self.nIndex += 1
+                            self.nCount += 1
+                            self.logger.debug("%s: %s", ii[0], ii[1])
+                            self.logger.info("Next link=%s", ii[1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get OData
+    def getOData(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/OData"
+        self.logger.info(
+            "--> getOData [%s %s]", self.method, self.url)
+        self.payload = None
+        if (self.connection == None):
+            self.connection = http.client.HTTPSConnection(
+                self.hostname, self.port, timeout=self.theTimeout)
+            self.logger.debug("Start the http connection")
+        response = self.rfRequest()
+        # Get the next link of getOData
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'value':
+                    if (self.get_logVerbose() >= 3):
+                        self.logger.debug(
+                            "%s: %s", i[0], json.dumps(i[1], indent=4))
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
     # Login
     def login(self):
         """ Login and start a REST session.  Remember to call logout() when you are done. """
         self.url = "/redfish/v1/SessionService/Sessions"
         self.method = "POST"
         self.logger.info("--> Login [%s %s]", self.method, self.url)
-        self.connection = http.client.HTTPSConnection(
-            self.hostname, self.port, timeout=self.theTimeout)
+        if (not self.connection):
+            self.connection = http.client.HTTPSConnection(
+                self.hostname, self.port, timeout=self.theTimeout)
+            self.logger.debug("Start the http connection")
         data = dict()
         data['UserName'] = self.username
         data['Password'] = self.password
@@ -198,7 +278,7 @@ class redfish_advantech:
 
         response = self.rfRequest(self)
         result = response.read().decode(errors='replace')
-        if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+        if (self.get_logVerbose() >= 1):
             self.logger.debug("result=%s", result)
         # Get Token and Location of session after login
         self.authToken = response.headers['X-Auth-Token']
@@ -231,7 +311,8 @@ class redfish_advantech:
 
     # Disconnect
     def disconnect(self):
-        self.logger.debug("---> Disconnect http self.connection")
+        if (self.get_logVerbose() >= 1): 
+            self.logger.debug("=== Disconnecting http redfish_advantech.connection ===")
         if (self.connection):
             try:
                 ret = self.connection.close()
@@ -250,6 +331,308 @@ class redfish_advantech:
         self.connection = None
         self.logger.debug('=== End to of redfish_advantech.disconnect ===')
 
+    # Get SessionService
+    def getSessionService(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/SessionService"
+        self.logger.info(
+            "--> getSessionService [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of SessionService
+        self.url = ''
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'Sessions':
+                    json_data2 = i[1]
+                    for ii in json_data2.items():
+                        if ii[0] == '@odata.id':
+                            self.url = ii[1]
+                    self.logger.debug("%s: %s", i[0], i[1])
+                    self.logger.info("Next link=%s", self.url)
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get SessionService/Sessions
+    def getSessionServiceSessions(self):
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        if (self.url != ''):
+            #self.url = self.urlEthernetInterfaces
+            self.method = "GET"
+            self.logger.info(
+                "--> getSessionServiceSessions [%s %s]", self.method, self.url)
+            self.payload = None
+            response = self.rfRequest()
+            result = response.read().decode(errors='replace')
+            if (response.getcode() == 200):
+                json_data = json.loads(result)
+                for i in json_data.items():
+                    if i[0] == 'Members@odata.count':
+                        self.nCount = i[1]
+                    if i[0] == 'Members':
+                        if (self.get_logVerbose() >= 2):
+                            self.logger.debug(
+                                "%s: %s", i[0], json.dumps(i[1], indent=4))
+                    else:
+                        self.logger.debug("%s: %s", i[0], i[1])
+        # Get the next link(s) of getSessionServiceSessions
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'Members@odata.count':
+                    self.nCount = i[1]
+                elif i[0] == 'Members':
+                    json_data2 = dict(enumerate(i[1]))
+                    for ii in json_data2.items():
+                        for iii in ii[1].items():
+                            if iii[0] == '@odata.id':
+                                self.lstURL.append(iii[1])
+                                self.nIndex += 1
+                                if (self.get_logVerbose() >= 2):
+                                    self.logger.info(
+                                        "Next link=%s", self.lstURL[self.nIndex-1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get SessionService/Sessions/*
+    def getSessionServiceSessionsAll(self):
+        for i in range(self.nCount):
+            if (self.lstURL[i] != ''):
+                self.url = self.lstURL[i]
+                self.method = "GET"
+                self.logger.debug(
+                    "--> getSessionServiceSessionsAll [%s %s]", self.method, self.url)
+                self.payload = None
+                response = self.rfRequest()
+                result = response.read().decode(errors='replace')
+                if (self.get_logVerbose() >= 2):
+                    self.logger.debug(result)
+                if (response.getcode() == 200):
+                    json_data = json.loads(result)
+                    for i in json_data.items():
+                        if (self.get_logVerbose() >= 1):
+                            self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService
+    def getAccountService(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/AccountService"
+        self.logger.info(
+            "--> getAccountService [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of AccountService
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if (i[0] in {"Accounts", "Roles", "PrivilegeMap"}):
+                    json_data2 = i[1]
+                    for ii in json_data2.items():
+                        if ii[0] == '@odata.id':
+                            self.lstURL.append(ii[1])
+                            self.nIndex += 1
+                            self.nCount += 1
+                            self.logger.debug("%s: %s", ii[0], ii[1])
+                            self.logger.info("Next link=%s", ii[1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService/Accounts
+    def getAccountServiceAccounts(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/AccountService/Accounts"
+        self.logger.info(
+            "--> getAccountServiceAccounts [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of AccountServiceAccounts
+        self.lstURL2 = []
+        self.nCount2 = 0
+        self.nIndex2 = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        # Get the next link(s) of AccountServiceAccounts
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'Members@odata.count':
+                    self.nCount2 = i[1]
+                elif i[0] == 'Members':
+                    json_data2 = dict(enumerate(i[1]))
+                    for ii in json_data2.items():
+                        for iii in ii[1].items():
+                            if iii[0] == '@odata.id':
+                                self.lstURL2.append(iii[1])
+                                self.nIndex2 += 1
+                                if (self.get_logVerbose() >= 1):
+                                    self.logger.info(
+                                        "Next link=%s", self.lstURL2[self.nIndex2-1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService/Accounts/*
+    def getAccountServiceAccountsAll(self):
+        for i in range(self.nCount2):
+            if (self.lstURL2[i] != ''):
+                self.url = self.lstURL2[i]
+                self.method = "GET"
+                self.logger.debug(
+                    "--> getAccountServiceAccountsAll [%s %s]", self.method, self.url)
+                self.payload = None
+                response = self.rfRequest()
+                result = response.read().decode(errors='replace')
+                if (self.get_logVerbose() >= 1):
+                    self.logger.debug(result)
+                if (response.getcode() == 200):
+                    json_data = json.loads(result)
+                    for i in json_data.items():
+                        if (self.get_logVerbose() >= 1):
+                            self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService/Roles
+    def getAccountServiceRoles(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/AccountService/Roles"
+        self.logger.info(
+            "--> getAccountServiceRoles [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of getAccountServiceRoles
+        self.lstURL2 = []
+        self.nCount2 = 0
+        self.nIndex2 = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        # Get the next link(s) of AccountServiceAccounts
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'Members@odata.count':
+                    self.nCount2 = i[1]
+                elif i[0] == 'Members':
+                    json_data2 = dict(enumerate(i[1]))
+                    for ii in json_data2.items():
+                        for iii in ii[1].items():
+                            if iii[0] == '@odata.id':
+                                self.lstURL2.append(iii[1])
+                                self.nIndex2 += 1
+                                if (self.get_logVerbose() >= 1):
+                                    self.logger.info(
+                                        "Next link=%s", self.lstURL2[self.nIndex2-1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService/Roles/*
+    def getAccountServiceRolesAll(self):
+        for i in range(self.nCount2):
+            if (self.lstURL2[i] != ''):
+                self.url = self.lstURL2[i]
+                self.method = "GET"
+                self.logger.debug(
+                    "--> getAccountServiceRolesAll [%s %s]", self.method, self.url)
+                self.payload = None
+                response = self.rfRequest()
+                result = response.read().decode(errors='replace')
+                if (self.get_logVerbose() >= 1):
+                    self.logger.debug(result)
+                if (response.getcode() == 200):
+                    json_data = json.loads(result)
+                    for i in json_data.items():
+                        if (self.get_logVerbose() >= 1):
+                            self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get AccountService/PrivilegeMap
+    def getAccountServicePrivilegeMap(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/AccountService/PrivilegeMap"
+        self.logger.info(
+            "--> getAccountServicePrivilegeMap [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of getAccountServicePrivilegeMap
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 3):
+            self.logger.debug("result=%s", result)
+
+    # Get EventService
+    def getEventService(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/EventService"
+        self.logger.info(
+            "--> getEventService [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of EventService
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if (i[0] in {"Subscriptions"}):
+                    json_data2 = i[1]
+                    for ii in json_data2.items():
+                        if ii[0] == '@odata.id':
+                            self.lstURL.append(ii[1])
+                            self.nIndex += 1
+                            self.nCount += 1
+                            self.logger.debug("%s: %s", ii[0], ii[1])
+                            self.logger.info("Next link=%s", ii[1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+    # Get EventService/Subscriptions
+    def getEventServiceSubscriptions(self):
+        self.method = "GET"
+        self.url = "/redfish/v1/EventService/Subscriptions"
+        self.logger.info(
+            "--> getEventServiceSubscriptions [%s %s]", self.method, self.url)
+        self.payload = None
+        response = self.rfRequest()
+        # Get the next link of AccountService
+        self.lstURL = []
+        self.nCount = 0
+        self.nIndex = 0
+        result = response.read().decode(errors='replace')
+        if (self.get_logVerbose() >= 1):
+            self.logger.debug("result=%s", result)
+        # Get the next link(s) of getEventServiceSubscriptions
+        if (response.getcode() == 200):
+            json_data = json.loads(result)
+            for i in json_data.items():
+                if i[0] == 'Members@odata.count':
+                    self.nCount = i[1]
+                elif i[0] == 'Members':
+                    json_data2 = dict(enumerate(i[1]))
+                    for ii in json_data2.items():
+                        for iii in ii[1].items():
+                            if iii[0] == '@odata.id':
+                                self.lstURL.append(iii[1])
+                                self.nIndex += 1
+                                if (self.get_logVerbose() >= 1):
+                                    self.logger.info(
+                                        "Next link=%s", self.lstURL[self.nIndex-1])
+                else:
+                    self.logger.debug("%s: %s", i[0], i[1])
+
+                                    
     # Get Chassis
     def getChassis(self):
         self.method = "GET"
@@ -260,7 +643,7 @@ class redfish_advantech:
         # Get the next link of Chassis
         self.url = ''
         result = response.read().decode(errors='replace')
-        if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+        if (self.get_logVerbose() >= 1):
             self.logger.debug("result=%s", result)
         if (response.getcode() == 200):
             json_data = json.loads(result)
@@ -283,7 +666,7 @@ class redfish_advantech:
             self.logger.info("--> getChassis1u [%s %s]", self.method, self.url)
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug("result=%s", result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -316,7 +699,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -358,7 +741,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -398,7 +781,7 @@ class redfish_advantech:
         self.payload = None
         response = self.rfRequest()
         result = response.read().decode(errors='replace')
-        if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+        if (self.get_logVerbose() >= 1):
             self.logger.debug(result)
         # Get the next link of Systems
         self.url = ''
@@ -424,7 +807,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -491,7 +874,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             # Get contents of Systems/Bios
             if (response.getcode() == 200):
@@ -509,7 +892,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             # Get contents of Systems/Bios
             if (response.getcode() == 200):
@@ -540,7 +923,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             # Get contents of Systems/Bios
             if (response.getcode() == 200):
@@ -558,7 +941,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             # Get contents of Systems/Bios
             if (response.getcode() == 200):
@@ -594,7 +977,7 @@ class redfish_advantech:
                 self.payload = None
                 response = self.rfRequest()
                 result = response.read().decode(errors='replace')
-                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+                if (self.get_logVerbose() >= 1):
                     self.logger.debug(result)
                 if (response.getcode() == 200):
                     json_data = json.loads(result)
@@ -611,7 +994,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -649,7 +1032,7 @@ class redfish_advantech:
                 self.payload = None
                 response = self.rfRequest()
                 result = response.read().decode(errors='replace')
-                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+                if (self.get_logVerbose() >= 1):
                     self.logger.debug(result)
                 if (response.getcode() == 200):
                     json_data = json.loads(result)
@@ -666,6 +1049,8 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
+            if (self.get_logVerbose() >= 1):
+                self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
                 for i in json_data.items():
@@ -702,7 +1087,7 @@ class redfish_advantech:
                 self.payload = None
                 response = self.rfRequest()
                 result = response.read().decode(errors='replace')
-                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+                if (self.get_logVerbose() >= 1):
                     self.logger.debug(result)
                 if (response.getcode() == 200):
                     json_data = json.loads(result)
@@ -719,7 +1104,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -758,7 +1143,7 @@ class redfish_advantech:
                 self.payload = None
                 response = self.rfRequest()
                 result = response.read().decode(errors='replace')
-                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+                if (self.get_logVerbose() >= 1):
                     self.logger.debug(result)
                 if (response.getcode() == 200):
                     json_data = json.loads(result)
@@ -783,7 +1168,7 @@ class redfish_advantech:
             self.payload = None
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 2):
+            if (self.get_logVerbose() >= 2):
                 self.logger.debug(result)
             if (response.getcode() == 200):
                 json_data = json.loads(result)
@@ -808,7 +1193,7 @@ class redfish_advantech:
                             if iii[0] == '@odata.id':
                                 self.lstURL.append(iii[1])
                                 self.nIndex = self.nIndex + 1
-                                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 2):
+                                if (self.get_logVerbose() >= 2):
                                     self.logger.debug(
                                         "Next link=%s", self.lstURL[self.nIndex-1])
                 else:
@@ -816,17 +1201,22 @@ class redfish_advantech:
         # Get Systems/0/LogServices/Log/Entries/*
         for i in range(self.nCount):
             if (self.lstURL[i] != ''):
+                if (self.get_logVerbose() <= 1):
+                    if i < self.nCount - 1:
+                        print("\rLogServicesLogEntries({})={}".format(i+1, self.lstURL[i]), end = '')
+                    else:
+                        print("\rLogServicesLogEntries({})={}".format(i+1, self.lstURL[i]))
                 self.url = self.lstURL[i]
                 self.method = "GET"
                 self.payload = None
                 response = self.rfRequest(False)
                 result = response.read().decode(errors='replace')
-                if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 2):
+                if (self.get_logVerbose() >= 3):
                     self.logger.debug(result)
                 if (response.getcode() == 200):
                     json_data = json.loads(result)
                     for i in json_data.items():
-                        if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 2):
+                        if (self.get_logVerbose() >= 2):
                             self.logger.debug("%s: %s", i[0], i[1])
 
     # GracefulShutdown or Power on
@@ -850,7 +1240,6 @@ class redfish_advantech:
                 self.logger.info('self.payload Power On')
             response = self.rfRequest()
             result = response.read().decode(errors='replace')
-            if (self.logger.isEnabledFor(logging.DEBUG) and self.get_logVerbose() >= 1):
+            if (self.get_logVerbose() >= 1):
                 self.logger.debug(result)
-        self.payload = None
-
+        self.payload = None
\ No newline at end of file
